@@ -2,13 +2,15 @@ from django.contrib.auth import get_user_model
 from django.utils import timezone
 
 from django.apps import apps
+from django.db.models import ImageField
 
 from rest_framework import serializers
 
 from comment.conf import settings
 from comment.models import Comment, Flag, Reaction
-from comment.utils import get_model_obj, process_anonymous_commenting, get_user_for_request, get_profile_instance
+from comment.utils import get_user_for_request, get_profile_instance
 from comment.messages import EmailError
+from comment.mixins import CommentCreateMixin
 
 
 def get_profile_model():
@@ -22,36 +24,38 @@ def get_profile_model():
 def get_user_fields():
     user_model = get_user_model()
     fields = user_model._meta.get_fields()
+    api_fields = list(settings.COMMENT_USER_API_FIELDS) + ['profile']
+    api_fields = list(set(api_fields))
     for field in fields:
-        if hasattr(field, "upload_to"):
-            return 'id', 'username', 'email', 'profile', field.name
-    return 'id', 'username', 'email', 'profile'
+        if hasattr(field, "upload_to") and isinstance(field, ImageField):
+            api_fields.append(field.name)
+    return api_fields
 
 
-class ProfileSerializer(serializers.ModelSerializer):
+class ProfileSerializerDAB(serializers.ModelSerializer):
     class Meta:
         model = get_profile_model()
         fields = getattr(settings, 'COMMENT_PROFILE_API_FIELDS', '__all__')
 
 
-class UserSerializer(serializers.ModelSerializer):
+class UserSerializerDAB(serializers.ModelSerializer):
     profile = serializers.SerializerMethodField()
 
     class Meta:
         model = get_user_model()
         fields = get_user_fields()
-        lookup_field = 'username'
+        lookup_field = model.USERNAME_FIELD
 
     @staticmethod
     def get_profile(obj):
         profile = get_profile_instance(obj)
         if not profile:
             return None
-        return ProfileSerializer(profile).data
+        return ProfileSerializerDAB(profile).data
 
 
 class BaseCommentSerializer(serializers.ModelSerializer):
-    user = UserSerializer(read_only=True)
+    user = UserSerializerDAB(read_only=True)
     parent = serializers.SerializerMethodField()
     replies = serializers.SerializerMethodField()
     reply_count = serializers.SerializerMethodField()
@@ -90,18 +94,15 @@ class BaseCommentSerializer(serializers.ModelSerializer):
         return ReactionSerializer(obj.reaction).data
 
 
-class CommentCreateSerializer(BaseCommentSerializer):
+class CommentCreateSerializer(BaseCommentSerializer, CommentCreateMixin):
     class Meta:
         model = Comment
         fields = ('id', 'user', 'email', 'content', 'parent', 'posted', 'edited', 'reply_count', 'replies', 'urlhash')
 
     def __init__(self, *args, **kwargs):
-        self.model_name = kwargs['context'].get('model_name')
-        self.app_name = kwargs['context'].get('app_name')
-        self.model_id = kwargs['context'].get('model_id')
-        self.user = kwargs['context'].get('user')
-        self.parent_id = kwargs['context'].get('parent_id')
-        if kwargs['context']['request'].user.is_authenticated or not settings.COMMENT_ALLOW_ANONYMOUS:
+        user = kwargs['context']['request'].user
+        self.email_service = None
+        if user.is_authenticated or not settings.COMMENT_ALLOW_ANONYMOUS:
             del self.fields['email']
 
         super().__init__(*args, **kwargs)
@@ -117,24 +118,17 @@ class CommentCreateSerializer(BaseCommentSerializer):
         user = get_user_for_request(request)
         content = validated_data.get('content')
         email = validated_data.get('email')
-        parent_id = self.parent_id
         time_posted = timezone.now()
-        parent_comment = Comment.objects.get_parent_comment(parent_id)
-        model_object = get_model_obj(self.app_name, self.model_name, self.model_id)
 
-        comment = Comment(
-            content_object=model_object,
+        temp_comment = Comment(
+            content_object=self.context['model_obj'],
             content=content,
             user=user,
-            parent=parent_comment,
+            parent=self.context['parent_comment'],
             email=email,
             posted=time_posted
-            )
-        if settings.COMMENT_ALLOW_ANONYMOUS and not user:
-            process_anonymous_commenting(request, comment, api=True)
-        else:
-            comment.save()
-        return comment
+        )
+        return self.perform_create(temp_comment, request, api=True)
 
 
 class CommentSerializer(BaseCommentSerializer):
@@ -172,10 +166,15 @@ class ReactionSerializer(serializers.ModelSerializer):
     def get_users(obj):
         users = {'likes': [], 'dislikes': []}
         for instance in obj.reactions.all():
+            user_info = {
+                'id': instance.user.id,
+                'username': instance.user.USERNAME_FIELD
+            }
+
             if instance.reaction_type == instance.ReactionType.LIKE:
-                users['likes'].append({'id': instance.user.id, 'username': instance.user.username})
+                users['likes'].append(user_info)
             else:
-                users['dislikes'].append({'id': instance.user.id, 'username': instance.user.username})
+                users['dislikes'].append(user_info)
         return users
 
 
@@ -190,7 +189,11 @@ class FlagSerializer(serializers.ModelSerializer):
     @staticmethod
     def get_reporters(obj):
         return [
-            {'id': flag_instance.user.id, 'username': flag_instance.user.username} for flag_instance in obj.flags.all()
+            {
+                'id': flag_instance.user.id,
+                'username': flag_instance.user.USERNAME_FIELD
+            }
+            for flag_instance in obj.flags.all()
         ]
 
     @staticmethod
