@@ -15,6 +15,8 @@ urlpatterns = [
         name='comments-flag-state-change'
     ),
     re_path(r'^comments/confirm/(?P<key>[^/]+)/$', views.ConfirmComment.as_view(), name='confirm-comment'),
+    path('comments/toggle-subscription/', views.ToggleFollowAPI.as_view(), name='toggle-subscription'),
+    path('comments/subscribers/', views.SubscribersAPI.as_view(), name='subscribers'),
 ]
 
 urlpatterns = format_suffix_patterns(urlpatterns)
