@@ -2,10 +2,11 @@ from django.urls import path, re_path
 from django.views.decorators.cache import cache_page
 from django.views.i18n import JavaScriptCatalog
 
-from comment import _get_version
+from comment import __version__
 from comment.views import (
     CreateComment, UpdateComment, DeleteComment, SetReaction, SetFlag, ChangeFlagState,
-    ConfirmComment)
+    ConfirmComment, ToggleFollowView
+)
 
 app_name = 'comment'
 
@@ -18,10 +19,11 @@ urlpatterns = [
     path('<int:pk>/flag/', SetFlag.as_view(), name='flag'),
     path('<int:pk>/flag/state/change/', ChangeFlagState.as_view(), name='flag-change-state'),
     re_path(r'^confirm/(?P<key>[^/]+)/$', ConfirmComment.as_view(), name='confirm-comment'),
+    path('toggle-subscription/', ToggleFollowView.as_view(), name='toggle-subscription'),
     # javascript translations
     # The value returned by _get_version() must change when translations change.
     path(
         'jsi18n/',
-        cache_page(86400, key_prefix='js18n-%s' % _get_version())(JavaScriptCatalog.as_view()),
+        cache_page(86400, key_prefix='js18n-%s' % __version__)(JavaScriptCatalog.as_view()),
         name='javascript-catalog'),
 ]
